==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/reef/dialogs_nl.lua <==

dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
dialogStr("Lieve Hemel, door de inslag is het hier ingestort!")


dialogId("uts-v-projet0", "font_big", "I can’t go through this cave-in, we have to find another exit.")
dialogStr("Ik kom hier nooit doorheen. We moeten een andere uitgang zoeken.")


dialogId("uts-v-projet1", "font_big", "This is not the way.")
dialogStr("Dit gaat niet.")


dialogId("uts-v-sam", "font_big", "I won’t make it alone.")
dialogStr("Dit lukt me niet in m'n eentje.")


dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
dialogStr("Ik had misschien beter die schelp eerst op kunnen tillen.")


dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")
dialogStr("Misschien moeten we deze dingen omwisselen.")


dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")
dialogStr("Een matras. Het allerhandigste om onderwater bij je te hebben.")


dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")
dialogStr("Nu kunnen we de slak op de matras laten vallen.")


dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
dialogStr("Het gaat lastig worden de slak van daaraf op te tillen.")


dialogId("uts-v-konecne", "font_big", "Finally, it’s there.")
dialogStr("Eindelijk is hij er.")


dialogId("uts-m-chudak", "font_small", "The poor snail...")
dialogStr("Arm slakje...")


dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
dialogStr("We moeten het koraalrif systematisch doorzoeken.")


dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
dialogStr("Er zullen daar vast veel interessante wezens te onderzoeken zijn.")


dialogId("uts-v-mikroskop", "font_big", "Don’t we need a microscope to investigate corals?")
dialogStr("Hebben we geen microscoop nodig, als we koralen willen bekijken?")


dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
dialogStr("Ja, die zijn inderdaad klein, maar er kunnen ook andere levensvormen tussen wonen.")


dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")
dialogStr("Bij voorbeeld koraalschildpadden.")


dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there's a microscope in a bathyscaph.")
dialogStr("En bovendien heb ik een donkerbruin vermoeden dat er een microscoop in een bathyscaaf ligt ergens.")

==> fillets-ng-data_0.9.2.orig.tar.gz: fillets-ng-data-0.9.2/script/reef/dialogs_nl.lua <==

dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
dialogStr("Lieve Hemel, door de inslag is het hier ingestort!")


dialogId("uts-v-projet0", "font_big", "I can’t go through this cave-in, we have to find another exit.")
dialogStr("Ik kom hier nooit doorheen. We moeten een andere uitgang zoeken.")


dialogId("uts-v-projet1", "font_big", "This is not the way.")
dialogStr("Dit gaat niet.")


dialogId("uts-v-sam", "font_big", "I won’t make it alone.")
dialogStr("Dit lukt me niet in m'n eentje.")


dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
dialogStr("Ik had misschien beter die schelp eerst op kunnen tillen.")


dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")
dialogStr("Misschien moeten we deze dingen omwisselen.")


dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")
dialogStr("Een matras. Het allerhandigste om onderwater bij je te hebben.")


dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")
dialogStr("Nu kunnen we de slak op de matras laten vallen.")


dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
dialogStr("Het gaat lastig worden de slak van daaraf op te tillen.")


dialogId("uts-v-konecne", "font_big", "Finally, it’s there.")
dialogStr("Eindelijk is hij er.")


dialogId("uts-m-chudak", "font_small", "The poor snail...")
dialogStr("Arm slakje...")


dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
dialogStr("We moeten het koraalrif systematisch doorzoeken.")


dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
dialogStr("Er zullen daar vast veel interessante wezens te onderzoeken zijn.")


dialogId("uts-v-mikroskop", "font_big", "Don’t we need a microscope to investigate corals?")
dialogStr("Hebben we geen microscoop nodig, als we koralen willen bekijken?")


dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
dialogStr("Ja, die zijn inderdaad klein, maar er kunnen ook andere levensvormen tussen wonen.")


dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")
dialogStr("Bij voorbeeld koraalschildpadden.")


dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there’s a microscope in a bathyscaph.")
dialogStr("En bovendien heb ik een donkerbruin vermoeden dat er een microscoop in een bathyscaaf ligt ergens.")
